(function() {

    var Java = {
        init : function() {
            this.loadTarget(this.renderTable);

            $(document).bind('start-monitor', this.startMonitor);
            $(document).bind('load-completed', function() {
                setInterval(Java.startMonitor, 60 * 1000);
            });
        },

        loadTarget : function(fn) {
            $.getJSON(ctx + '/target?type=JAVA', function(json) {
                if (json.succeed) {
                    fn(json.data);

                    $(document).trigger('start-monitor');
                    $(document).trigger('load-completed');
                } else {
                    Toast.danger(json.msg);
                }
            });
        },

        loadLast : function(id, fn) {
            $.getJSON(ctx + '/statistics/last?targetId=' + id, function(json) {
                if (json.succeed) {
                    fn(json.data);
                } else {
                    Toast.danger(json.msg);
                }
            });
        },

        renderTable : function(array) {
            var table = $('table');

            $(array).each(function(i, item) {
                var tr = $('<tr name="target">');

                var id = $('<td name="id">').text(item.id);
                var name = $('<td>').text(item.name);
                var group = $('<td>').text(item.group);
                var used = $('<td name="used">').text('-');
                var max = $('<td name="max">').text('-');
                var threads = $('<td name="threads">').text('-');
                var status = $('<td name="status">').text('-');
                var time = $('<td name="time">').text('-');

                var history = $('<a class="btn btn-default btn-sm icon-dashboard" title="dashboard" href="' + ctx + '/java/dashboard?targetId=' + item.id + '"></a>')

                var operation = $('<td>').append(history);

                tr.append(id).append(name).append(group).append(used).append(max).append(threads).append(status).append(time).append(operation);

                table.find('tbody').append(tr);
            });
        },

        startMonitor : function() {
            var table = $('table');
            var rows = table.find('tbody tr[name=target]');
            $(rows).each(function(i, row) {
                var id = $(row).find('td[name=id]').text();
                Java.loadLast(id, function(data) {
                    // render this row
                    var available = data.available;
                    if (available) {
                        $(row).find('td[name=status]').html('<p class="bg-success running">RUNNING</p>');

                        var used = (data.heapMemory.used / data.heapMemory.max) * 100;
                        var color = RatioColor.getColor(100 - used);

                        $(row).find('td[name=used]').html(Progress.get(used, color));
                        $(row).find('td[name=max]').html(Size.to(data.heapMemory.max));
                        $(row).find('td[name=threads]').html(data.thread.thread);
                    } else {
                        $(row).find('td[name=status]').html('<p class="bg-danger stoped">STOPED</p>');
                        $(row).find('td[name=used]').html('-');
                        $(row).find('td[name=max]').html('-');
                        $(row).find('td[name=threads]').html('-');
                    }
                    $(row).find('td[name=time]').html(DateUtil.format(data.time, 'yyyy-MM-dd HH:mm:ss'));
                });
            });
        }
    };

    $(function() {
        Java.init();
    })

})(jQuery);